package com.ruoyi.bst.booth.service.impl;

import java.util.List;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.part.domain.PartVO;
import com.ruoyi.bst.part.service.PartService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.booth.mapper.BoothMapper;
import com.ruoyi.bst.booth.domain.Booth;
import com.ruoyi.bst.booth.domain.BoothVO;
import com.ruoyi.bst.booth.domain.BoothQuery;
import com.ruoyi.bst.booth.service.BoothService;

/**
 * 卡座Service业务层处理
 *
 * @author ruoyi
 * @date 2025-04-18
 */
@Service
public class BoothServiceImpl implements BoothService
{
    @Autowired
    private BoothMapper boothMapper;
    @Autowired
    private PartService partService;

    /**
     * 查询卡座
     *
     * @param scope 卡座主键
     * @return 卡座
     */
    @Override
    public BoothVO selectBoothByBoothId(Long id, boolean scope)
    {
        if (id == null) {
            return null;
        }
        BoothQuery query = new BoothQuery();
        query.setBoothId(id);
        query.setScope(scope);
        return this.selectOne(query);
    }

    @Override
    public BoothVO selectOne(BoothQuery query) {
        PageHelper.startPage(1, 1);
        List<BoothVO> list = this.selectBoothList(query);
        return CollectionUtils.firstElement(list);
    }
    /**
     * 查询卡座列表
     *
     * @param booth 卡座
     * @return 卡座
     */
    @Override
    public List<BoothVO> selectBoothList(BoothQuery booth)
    {
        return boothMapper.selectBoothList(booth);
    }

    /**
     * 新增卡座
     *
     * @param booth 卡座
     * @return 结果
     */
    @Override
    public int insertBooth(Booth booth)
    {
        booth.setCreateTime(DateUtils.getNowDate());
        return boothMapper.insertBooth(booth);
    }

    /**
     * 修改卡座
     *
     * @param booth 卡座
     * @return 结果
     */
    @Override
    public int updateBooth(Booth booth)
    {
        return boothMapper.updateBooth(booth);
    }

    /**
     * 批量删除卡座
     *
     * @param boothIds 需要删除的卡座主键
     * @return 结果
     */
    @Override
    public int deleteBoothByBoothIds(List<Long> boothIds)
    {
        return boothMapper.deleteBoothByBoothIds(boothIds);
    }

    /**
     * 删除卡座信息
     *
     * @param boothId 卡座主键
     * @return 结果
     */
    @Override
    public int deleteBoothByBoothId(Long boothId)
    {
        return boothMapper.deleteBoothByBoothId(boothId);
    }

    @Override
    public Long getUserId(Booth booth) {
        PartVO part = partService.selectPartById(booth.getPartId());
        return partService.getUserId(part);
    }
}
