package com.ruoyi.bst.floor.service.impl;

import java.util.List;

import com.github.pagehelper.PageHelper;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.floor.mapper.FloorMapper;
import com.ruoyi.bst.floor.domain.Floor;
import com.ruoyi.bst.floor.domain.FloorVO;
import com.ruoyi.bst.floor.domain.FloorQuery;
import com.ruoyi.bst.floor.service.FloorService;

/**
 * 楼层列表Service业务层处理
 *
 * @author ruoyi
 * @date 2025-04-22
 */
@Service
public class FloorServiceImpl implements FloorService
{
    @Autowired
    private FloorMapper floorMapper;

    /**
     * 查询楼层列表
     *
     * @param id 楼层列表主键
     * @return 楼层列表
     */
    @Override
    public FloorVO selectFloorByFloorId(Long id, boolean scope)
    {
        if (id == null) {
            return null;
        }
        FloorQuery query = new FloorQuery();
        query.setFloorId(id);
        query.setScope(scope);
        return this.selectOne(query);
    }

    @Override
    public FloorVO selectOne(FloorQuery query) {
        PageHelper.startPage(1, 1);
        List<FloorVO> list = floorMapper.selectFloorList(query);
        return CollectionUtils.firstElement(list);
    }
    /**
     * 查询楼层列表列表
     *
     * @param floor 楼层列表
     * @return 楼层列表
     */
    @Override
    public List<FloorVO> selectFloorList(FloorQuery floor)
    {
        return floorMapper.selectFloorList(floor);
    }

    /**
     * 新增楼层列表
     *
     * @param floor 楼层列表
     * @return 结果
     */
    @Override
    public int insertFloor(Floor floor)
    {
        floor.setCreateTime(DateUtils.getNowDate());
        return floorMapper.insertFloor(floor);
    }

    /**
     * 修改楼层列表
     *
     * @param floor 楼层列表
     * @return 结果
     */
    @Override
    public int updateFloor(Floor floor)
    {
        return floorMapper.updateFloor(floor);
    }

    /**
     * 批量删除楼层列表
     *
     * @param floorIds 需要删除的楼层列表主键
     * @return 结果
     */
    @Override
    public int deleteFloorByFloorIds(List<Long> floorIds)
    {
        return floorMapper.deleteFloorByFloorIds(floorIds);
    }

    /**
     * 删除楼层列表信息
     *
     * @param floorId 楼层列表主键
     * @return 结果
     */
    @Override
    public int deleteFloorByFloorId(Long floorId)
    {
        return floorMapper.deleteFloorByFloorId(floorId);
    }
}
