package com.ruoyi.bst.floor.service.impl;

import com.ruoyi.bst.floor.domain.FloorQuery;
import com.ruoyi.bst.floor.mapper.FloorMapper;
import com.ruoyi.bst.floor.service.FloorValidator;
import com.ruoyi.bst.part.domain.PartQuery;
import com.ruoyi.bst.part.mapper.PartMapper;
import com.ruoyi.bst.part.service.PartValidator;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.HashSet;
import java.util.List;

@Service
public class FloorValidatorImpl implements FloorValidator {

    @Autowired
    private PartMapper partMapper;
    @Autowired
    private FloorMapper floorMapper;

    @Override
    public boolean canCheckForFloor(Long partId) {
        return canOperate(Arrays.asList(partId));
    }

    @Override
    public boolean canEdit(Long partId) {
        return canOperate(Arrays.asList(partId));
    }

    @Override
    public boolean canDeleteAll(List<Long> partIds) {
        return canOperate(partIds);
    }

    // 是否可以操作运营区
    private boolean canOperate(List<Long> partIds) {
        return hasPermission(partIds);
    }

    // 是否有运营区权限
    private boolean hasPermission(List<Long> partIds) {
        if (SecurityUtils.isSysAdmin()) {
            return true;
        }
        if (CollectionUtils.isEmptyElement(partIds)) {
            return true;
        }
        // 查询运营区
        FloorQuery query = new FloorQuery();
        query.setIds(partIds);
        query.setScope(true);
        List<Long> floorList = floorMapper.selectIdByQuery(query);
        return new HashSet<>(floorList).containsAll(partIds);
    }

}
