package com.ruoyi.bst.order.mapper;

import java.util.List;
import com.ruoyi.bst.order.domain.Order;
import com.ruoyi.bst.order.domain.OrderVO;
import com.ruoyi.bst.order.domain.OrderQuery;
import org.apache.ibatis.annotations.Param;

/**
 * 订单列表Mapper接口
 *
 * @author ruoyi
 * @date 2025-04-26
 */
public interface OrderMapper
{
    /**
     * 查询订单列表
     *
     * @param id 订单列表主键
     * @return 订单列表
     */
    OrderVO selectOrderById(@Param("id") Long id);

    /**
     * 查询订单列表列表
     *
     * @param query 订单列表
     * @return 订单列表集合
     */
    List<OrderVO> selectOrderList(@Param("query")OrderQuery query);

    /**
     * 新增订单列表
     *
     * @param order 订单列表
     * @return 结果
     */
    int insertOrder(Order order);

    /**
     * 批量新增订单列表
     */
    int batchInsert(@Param("list") List<? extends Order> list);

    /**
     * 批量修改订单列表
     */
    int batchUpdate(@Param("list") List<? extends Order> list);

    /**
     * 修改订单列表
     *
     * @param order 订单列表
     * @return 结果
     */
    public int updateOrder(@Param("data") Order order);

    /**
     * 删除订单列表
     *
     * @param id 订单列表主键
     * @return 结果
     */
    int deleteOrderById(Long id);

    /**
     * 批量删除订单列表
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderByIds(Long[] ids);

    /**
     * 根据查询条件查询订单ID列表
     * @param query 查询条件
     * @return 订单ID列表
     */
    List<Long> selectIdByQuery(@Param("query") OrderQuery query);


    /**
     * 根据查询条件更新订单
     * @param data 更新数据
     * @param query 查询条件
     * @return 结果
     */
    int updateByQuery(@Param("data") Order data, @Param("query") OrderQuery query);

    OrderVO selectOrderByBstId(@Param("bstId") Long bstId);
}
