package com.ruoyi.web.bst;

import com.ruoyi.bst.changeRecord.domain.ChangeRecord;
import com.ruoyi.bst.changeRecord.domain.ChangeRecordQuery;
import com.ruoyi.bst.changeRecord.domain.ChangeRecordVO;
import com.ruoyi.bst.changeRecord.service.ChangeRecordService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 爆灯次数变化Controller
 *
 * @author ruoyi
 * @date 2025-04-26
 */
@RestController
@RequestMapping("/bst/changeRecord")
public class ChangeRecordController extends BaseController
{
    @Autowired
    private ChangeRecordService changeRecordService;

    /**
     * 查询爆灯次数变化列表
     */
    @PreAuthorize("@ss.hasPermi('bst:changeRecord:list')")
    @GetMapping("/list")
    public TableDataInfo list(ChangeRecordQuery query)
    {
        startPage();
        startOrderBy();
        List<ChangeRecordVO> list = changeRecordService.selectChangeRecordList(query);
        return getDataTable(list);
    }

    /**
     * 导出爆灯次数变化列表
     */
    @PreAuthorize("@ss.hasPermi('bst:changeRecord:export')")
    @Log(title = "爆灯次数变化", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ChangeRecordQuery query)
    {
        List<ChangeRecordVO> list = changeRecordService.selectChangeRecordList(query);
        ExcelUtil<ChangeRecordVO> util = new ExcelUtil<ChangeRecordVO>(ChangeRecordVO.class);
        util.exportExcel(response, list, "爆灯次数变化数据");
    }

    /**
     * 获取爆灯次数变化详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:changeRecord:query')")
    @GetMapping(value = "/{recordId}")
    public AjaxResult getInfo(@PathVariable("recordId") Long recordId)
    {
        return success(changeRecordService.selectChangeRecordByRecordId(recordId));
    }

    /**
     * 新增爆灯次数变化
     */
    @PreAuthorize("@ss.hasPermi('bst:changeRecord:add')")
    @Log(title = "爆灯次数变化", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ChangeRecord changeRecord)
    {
        return toAjax(changeRecordService.insertChangeRecord(changeRecord));
    }

    /**
     * 修改爆灯次数变化
     */
    @PreAuthorize("@ss.hasPermi('bst:changeRecord:edit')")
    @Log(title = "爆灯次数变化", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ChangeRecord changeRecord)
    {
        return toAjax(changeRecordService.updateChangeRecord(changeRecord));
    }

    /**
     * 删除爆灯次数变化
     */
    @PreAuthorize("@ss.hasPermi('bst:changeRecord:remove')")
    @Log(title = "爆灯次数变化", businessType = BusinessType.DELETE)
	@DeleteMapping("/{recordIds}")
    public AjaxResult remove(@PathVariable Long[] recordIds)
    {
        return toAjax(changeRecordService.deleteChangeRecordByRecordIds(recordIds));
    }
}
