package com.ruoyi.web.bst;

import com.ruoyi.bst.floor.domain.Floor;
import com.ruoyi.bst.floor.domain.FloorQuery;
import com.ruoyi.bst.floor.domain.FloorVO;
import com.ruoyi.bst.floor.service.FloorService;
import com.ruoyi.bst.floor.service.FloorValidator;
import com.ruoyi.bst.store.service.StoreValidator;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 楼层列表Controller
 *
 * @author ruoyi
 * @date 2025-04-22
 */
@RestController
@RequestMapping("/bst/floor")
public class FloorController extends BaseController
{
    @Autowired
    private FloorService floorService;
    @Autowired
    private StoreValidator storeValidator;
    @Autowired
    private FloorValidator floorValidator;

    /**
     * 查询楼层列表列表
     */
    @PreAuthorize("@ss.hasPermi('bst:floor:list')")
    @GetMapping("/list")
    public TableDataInfo list(FloorQuery query)
    {
        startPage();
        startOrderBy();
        query.setScope(true);
        List<FloorVO> list = floorService.selectFloorList(query);
        return getDataTable(list);
    }

    /**
     * 导出楼层列表列表
     */
    @PreAuthorize("@ss.hasPermi('bst:floor:export')")
    @Log(title = "楼层列表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FloorQuery query)
    {
        query.setScope(true);
        List<FloorVO> list = floorService.selectFloorList(query);
        ExcelUtil<FloorVO> util = new ExcelUtil<FloorVO>(FloorVO.class);
        util.exportExcel(response, list, "楼层列表数据");
    }

    /**
     * 获取楼层列表详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:floor:query')")
    @GetMapping(value = "/{floorId}")
    public AjaxResult getInfo(@PathVariable("floorId") Long floorId)
    {
        return success(floorService.selectFloorByFloorId(floorId,true));
    }

    /**
     * 新增楼层列表
     */
    @PreAuthorize("@ss.hasPermi('bst:floor:add')")
    @Log(title = "楼层列表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.Create.class) Floor floor)
    {
        // 判断能否选择店铺
        if (!storeValidator.canCheckForStore(floor.getStoreId())) {
            return AjaxResult.error("您无权选择ID为" + floor.getStoreId() + "的店铺");
        }
        return toAjax(floorService.insertFloor(floor));
    }

    /**
     * 修改楼层列表
     */
    @PreAuthorize("@ss.hasPermi('bst:floor:edit')")
    @Log(title = "楼层列表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated(ValidGroup.Update.class) Floor floor)
    {
        if (!floorValidator.canEdit(floor.getFloorId())) {
            return AjaxResult.error("您没有权限修改ID为" + floor.getFloorId() + "的楼层");
        }
        return toAjax(floorService.updateFloor(floor));
    }

    /**
     * 删除楼层列表
     */
    @PreAuthorize("@ss.hasPermi('bst:floor:remove')")
    @Log(title = "楼层列表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        if (!floorValidator.canDeleteAll(ids)) {
            return AjaxResult.error("您没有权限删除ID为" + ids + "的楼层");
        }
        return toAjax(floorService.deleteFloorByFloorIds(ids));
    }
}
