package com.ruoyi.web.bst;

import com.ruoyi.bst.store.domain.Store;
import com.ruoyi.bst.store.domain.StoreQuery;
import com.ruoyi.bst.store.domain.StoreVO;
import com.ruoyi.bst.store.service.StoreConverter;
import com.ruoyi.bst.store.service.StoreService;
import com.ruoyi.bst.store.service.StoreValidator;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.user.service.UserValidator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 店铺Controller
 *
 * @author ruoyi
 * @date 2025-04-18
 */
@RestController
@RequestMapping("/bst/store")
public class StoreController extends BaseController
{
    @Autowired
    private StoreService storeService;

    @Autowired
    private UserValidator userValidator;
    @Autowired
    private StoreValidator storeValidator;
    @Autowired
    private StoreConverter storeConverter;

    /**
     * 查询店铺列表
     */
    @PreAuthorize("@ss.hasPermi('bst:store:list')")
    @GetMapping("/list")
    public TableDataInfo list(StoreQuery query)
    {
        startPage();
        startOrderBy();
        query.setScope(true);
        query.setDeleted(false);
        List<StoreVO> list = storeService.selectStoreList(query);
        return getDataTable(list);
    }

    /**
     * 导出店铺列表
     */
    @PreAuthorize("@ss.hasPermi('bst:store:export')")
    @Log(title = "店铺", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, StoreQuery query)
    {
        query.setScope(true);
        List<StoreVO> list = storeService.selectStoreList(query);
        ExcelUtil<StoreVO> util = new ExcelUtil<StoreVO>(StoreVO.class);
        util.exportExcel(response, list, "店铺数据");
    }

    /**
     * 获取店铺详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:store:query')")
    @GetMapping(value = "/{storeId}")
    public AjaxResult getInfo(@PathVariable("storeId") Long storeId)
    {
        return success(storeService.selectStoreById(storeId,true));
    }

    /**
     * 新增店铺
     */
    @PreAuthorize("@ss.hasPermi('bst:store:add')")
    @Log(title = "店铺", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.Create.class) Store store)
    {
        // 若不能操作他人，则设置为当前用户
        if (!userValidator.canView(store.getUserId())) {
            store.setUserId(getUserId());
        }
        store.setUserId(getUserId());
        storeConverter.toPoByCreate(store);
        return toAjax(storeService.insertStore(store));
    }

    /**
     * 修改店铺
     */
    @PreAuthorize("@ss.hasPermi('bst:store:edit')")
    @Log(title = "店铺", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated(ValidGroup.Update.class) Store store)
    {
        if (!storeValidator.canEdit(store.getStoreId())){
            return AjaxResult.error("您没有权限修改ID为" + store.getStoreId() + "的商铺信息");
        }
        // 若不能操作他人，则不修改用户ID
        if (!userValidator.canView(store.getUserId())) {
            store.setUserId(null);
        }
        storeConverter.toPoByUpdate(store);
        return toAjax(storeService.updateStore(store));
    }

    /**
     * 删除店铺
     */
    @PreAuthorize("@ss.hasPermi('bst:store:remove')")
    @Log(title = "店铺", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable List<Long> ids)
    {
        if (!storeValidator.canDeleteAll(ids)) {
            return AjaxResult.error("您没有权限删除ID为" + ids + "的店铺信息");
        }
        return toAjax(storeService.logicDel(ids));
    }
}
